@@ -9,14 +9,23 @@ import (
 )
 
 const protocolName = "domainsocket"
+const sizeofSunPath = 108
 
 func (c *Config) GetUnixAddr() (*net.UnixAddr, error) {
 	path := c.Path
 	if path == "" {
 		return nil, newError("empty domain socket path")
 	}
-	if c.Abstract && path[0] != '\x00' {
-		path = "\x00" + path
+	if c.Abstract && path[0] != '@' {
+		path = "@" + path
+	}
+	if c.Abstract && c.Padding {
+		raw := []byte(path)
+		addr := make([]byte, sizeofSunPath)
+		for i, c := range raw {
+			addr[i] = c
+		}
+		path = string(addr)
 	}
 	return &net.UnixAddr{
 		Name: path,
